<?php
/**
 * Customizer functionality
 *
 * @package Signify
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since 1.0.0
 *
 * @see signify_header_style()
 */
function signify_custom_header_and_background() {
	$color_scheme             = signify_get_color_scheme();
	$default_background_color = trim( $color_scheme[0], '#' );
	$default_text_color       = trim( $color_scheme[1], '#' );

	/**
	 * Filter the arguments used when adding 'custom-background' support in Signify.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'signify_custom_background_args', array(
		'default-color' => $default_background_color,
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Signify.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'signify_custom_header_args', array(
		'default-image'      	 => get_parent_theme_file_uri( '/images/header-image.jpg' ),
		'default-text-color'     => $default_text_color,
		'width'                  => 1920,
		'height'                 => 1080,
		'flex-height'            => true,
		'flex-height'            => true,
		'wp-head-callback'       => 'signify_header_style',
		'video'                  => true,
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/images/header-image.jpg',
			'thumbnail_url' => '%s/images/header-image-275x155.jpg',
			'description'   => esc_html__( 'Default Header Image', 'signify-pro' ),
		),
		'second-image' => array(
			'url'           => '%s/images/header-image.jpg',
			'thumbnail_url' => '%s/images/header-image-275x155.jpg',
			'description'   => esc_html__( 'Alternate Header Image', 'signify-pro' ),
		),
	) );
}
add_action( 'after_setup_theme', 'signify_custom_header_and_background' );

function signify_color_options() {
	//Color Scheme
	$default_color = signify_get_color_scheme();

	// We do not add Background Color and Header Text Color here as if comes from WordPress Core
	return apply_filters( 'signify_color_options', array(
			'page_background_color'           => array(
				'label'   => esc_html__( 'Page Background Color', 'signify-pro' ),
				'default' => $default_color[2],
			),
			'secondary_background_color' => array(
				'label'   => esc_html__( 'Secondary Background Color', 'signify-pro' ),
				'default' => $default_color[3],
			),
			'absolute_header_background_color' => array(
				'label'   => esc_html__( 'Absolute Header Background Color for Inner Pages', 'signify-pro' ),
				'default' => $default_color[4],
			),
			'main_text_color'                 => array(
				'label'   => esc_html__( 'Main Text Color', 'signify-pro' ),
				'default' => $default_color[5],
			),
			'headline_text_color'         => array(
				'label'   => esc_html__( 'Headline Text Color', 'signify-pro' ),
				'default' => $default_color[6],
			),
			'tertiary_background'                           => array(
				'label'   => esc_html__( 'Tertiary Background', 'signify-pro' ),
				'default' => $default_color[7],
			),
			'link_color'                      => array(
				'label'   => esc_html__( 'Link Color', 'signify-pro' ),
				'default' => $default_color[8],
			),
			'link_hover_color'                => array(
				'label'   => esc_html__( 'Link Hover Color', 'signify-pro' ),
				'default' => $default_color[9],
			),
			'secondary_link_color'                      => array(
				'label'   => esc_html__( 'Secondary Link Color', 'signify-pro' ),
				'default' => $default_color[10],
			),
			'button_background_color'                         => array(
				'label'   => esc_html__( 'Button Background Color', 'signify-pro' ),
				'default' => $default_color[11],
			),
			'button_text_color'               => array(
				'label'   => esc_html__( 'Button Text Color', 'signify-pro' ),
				'default' => $default_color[12],
			),
			'tertiary_link_color'        => array(
				'label'   => esc_html__( 'Header and Tertiary Color', 'signify-pro' ),
				'default' => $default_color[13],
			),
			'button_hover_text_color'         => array(
				'label'   => esc_html__( 'Button Hover Text Color', 'signify-pro' ),
				'default' => $default_color[14],
			),
			'button_background_hover_color'                         => array(
				'label'   => esc_html__( 'Button Hover Background Color', 'signify-pro' ),
				'default' => $default_color[15],
			),
			'blog_background_odd'                         => array(
				'label'   => esc_html__( 'Blog Background Odd', 'signify-pro' ),
				'default' => $default_color[16],
			),
			'blog_background_even'                         => array(
				'label'   => esc_html__( 'Blog Background Even', 'signify-pro' ),
				'default' => $default_color[17],
			),
			'blog_background_even_color'                         => array(
				'label'   => esc_html__( 'Blog Background Even Color', 'signify-pro' ),
				'default' => $default_color[18],
			),
			'border_color'                => array(
				'label'   => esc_html__( 'Border Color', 'signify-pro' ),
				'default' => $default_color[19],
			),
			'textcolor_with_background'                    => array(
				'label'   => esc_html__( 'Text Color With Background', 'signify-pro' ),
				'default' => $default_color[20],
			),
			'team_section_title_color'                    => array(
				'label'   => esc_html__( 'Team section title color', 'signify-pro' ),
				'default' => $default_color[21],
			),
		)
	);
}

/**
 * Customize video play/pause button in the custom header.
 *
 * @param array $settings header video settings.
 */
function signify_video_controls( $settings ) {
	$settings['l10n']['play'] = '<span class="screen-reader-text">' . esc_html__( 'Play background video', 'signify-pro' ) . '</span>';
	$settings['l10n']['pause'] = '<span class="screen-reader-text">' . esc_html__( 'Pause background video', 'signify-pro' ) . '</span>';
	return $settings;
}
add_filter( 'header_video_settings', 'signify_video_controls' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since 1.0.0
 * @see signify_customize_register()
 *
 * @return void
 */
function signify_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since 1.0.0
 * @see signify_customize_register()
 *
 * @return void
 */
function signify_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Registers color schemes for Signify.
 *
 * Can be filtered with {@see 'signify_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Background Color
 * 2. Header Text Color
 * 3. Page Background Color
 * 4. Secondary Background Color
 * 5. Absolute Header Background Color for Inner Pages
 * 6. Main Text Color
 * 7. Headline Text Color
 * 8. Tertiary Background
 * 9. Link Color
 * 10. Link Hover Color
 * 11. Secondary Link Color
 * 12. Button Background Color
 * 13. Button Text Color
 * 14. Header and Tertiary Color
 * 15. Button Hover Text Color
 * 16. Button Hover Background Color
 * 17. Blog Background Odd
 * 18. Blog Background Even
 * 19. Blog Background Even Color
 * 20. Border Color
 * 21. Text Color With Background

 *
 * @since 1.0.0
 *
 * @return array An associative array of color scheme options.
 */
function signify_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Signify.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since 1.0.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'signify_color_schemes', array(
		'default' => array(
			'label'  => esc_html__( 'Default', 'signify-pro' ),
			'colors' => array(
				'#ffffff', /* Background Color */
				'#000000', /* Header Text Color */
				'#f2f5f8', /* Page Background Color */
				'#f6f6f6', /* Secondary Background Color */
				'#00e8b6', /* Absolute Header Background Color for Inner Pages */
				'#333333', /* Main Text Color */
				'#222222', /* Headline Text Color */
				'#131218', /* Tertiary Background */
				'#333333', /* Link Color */
				'#00e8b6', /* Link Hover Color */
				'#999999', /* Secondary Link Color */
				'#00e8b6', /* Button Background Color */
				'#03065d', /* Button Text Color */
				'#03065d', /* Header and Tertiary Color */
				'#ffffff', /* Button Hover Text Color */
				'#333333', /* Button Hover Background Color */
				'',        /* Blog Background Odd */
				'#060606', /* Blog Background Even */
				'#ffffff', /* Blog Background Even Color*/
				'#ebebeb', /* Border Color */
				'#ffffff', /* Text Color With Background */
				'#060606', /* Team section title color */
			),
		),
		'dark' => array( /* Dark */
			'label'  => esc_html__( 'Dark', 'signify-pro' ),
			'colors' => array(
				'#111111', /* Background Color */
				'#b7b7b7', /* Header Text Color */
				'#232323', /* Page Background Color */
				'#444141', /* Secondary Background Color */
				'#191919', /* Absolute Header Background Color for Inner Pages */
				'#717171', /* Main Text Color */
				'#ffffff', /* Headline Text Color */
				'#131218', /* Tertiary Background */
				'#ffffff', /* Link Color */
				'#00e8b6', /* Link Hover Color */
				'#686868', /* Secondary Link Color */
				'#00e8b6', /* Button Background Color */
				'#444444', /* Button Text Color */
				'#ffffff', /* Header and Tertiary Color */
				'#ffffff', /* Button Hover Text Color */
				'#333333', /* Button Hover Background Color */
				'',        /* Blog Background Odd */
				'#121212', /* Blog Background Even */
				'#ffffff', /* Blog Background Even Color*/
				'#555555', /* Border Color */
				'#ffffff', /* Text Color With Background */
				'#060606', /* Team section title color */
			),
		),
		'green' => array(
			'label'  => esc_html__( 'Green', 'signify-pro' ),
			'colors' => array(
				'#81d742', /* Background Color */
				'#03065d', /* Header Text Color */
				'#ffffff', /* Page Background Color */
				'#00d134', /* Secondary Background Color */
				'#81d742', /* Absolute Header Background Color for Inner Pages */
				'#333333', /* Main Text Color */
				'#222222', /* Headline Text Color */
				'#131218', /* Tertiary Background */
				'#333333', /* Link Color */
				'#00e8b6', /* Link Hover Color */
				'#999999', /* Secondary Link Color */
				'#00e8b6', /* Button Background Color */
				'#494949', /* Button Text Color */
				'#03065d', /* Header and Tertiary Color */
				'#ffffff', /* Button Hover Text Color */
				'#333333', /* Button Hover Background Color */
				'',        /* Blog Background Odd */
				'#060606', /* Blog Background Even */
				'#ffffff', /* Blog Background Even Color*/
				'#3ec940', /* Border Color */
				'#ffffff', /* Text Color With Background */
				'#060606', /* Team section title color */
			),
		),
	) );
}

if ( ! function_exists( 'signify_get_color_scheme' ) ) :
/**
 * Retrieves the current Signify color scheme.
 *
 * Create your own signify_get_color_scheme() function to override in a child theme.
 *
 * @since 1.0.0
 *
 * @return array An associative array of either the current or default color scheme HEX values.
 */
function signify_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
	$color_schemes       = signify_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default']['colors'];
}
endif; // signify_get_color_scheme

if ( ! function_exists( 'signify_get_color_scheme_choices' ) ) :
/**
 * Retrieves an array of color scheme choices registered for Signify.
 *
 * Create your own signify_get_color_scheme_choices() function to override
 * in a child theme.
 *
 * @since 1.0.0
 *
 * @return array Array of color schemes.
 */
function signify_get_color_scheme_choices() {
	$color_schemes                = signify_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // signify_get_color_scheme_choices


if ( ! function_exists( 'signify_sanitize_color_scheme' ) ) :
/**
 * Handles sanitization for Signify color schemes.
 *
 * Create your own signify_sanitize_color_scheme() function to override
 * in a child theme.
 *
 * @since 1.0.0
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function signify_sanitize_color_scheme( $value ) {
	$color_schemes = signify_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		return 'default';
	}

	return $value;
}
endif; // signify_sanitize_color_scheme

/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_color_scheme_css() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );

	// Don't do anything if the default color scheme is selected.
	if ( 'default' === $color_scheme_option ) {
		return;
	}

	$color_scheme = signify_get_color_scheme();

	// Convert Headline text color to rgba.
	$headline_text_color_rgb = signify_hex2rgb( $color_scheme[6] );

	// Convert Headline text color to rgba.
	$tertiary_background_rgb = signify_hex2rgb( $color_scheme[7] );

	// Convert link color to rgba.
	$link_color_rgb = signify_hex2rgb( $color_scheme[8] );

	// Convert Border color to rgba.
	$border_color_rgb = signify_hex2rgb( $color_scheme[19] );

	// Convert textcolor with background color to rgba.
	$textcolor_with_background_rgb = signify_hex2rgb( $color_scheme[20] );

	// If the rgba values are empty return early.
	if ( empty( $headline_text_color_rgb ) || empty( $link_color_rgb ) || empty( $tertiary_background_rgb )  || empty( $border_color_rgb ) || empty( $textcolor_with_background_rgb ) ) {
		return;
	}

	// If we get this far, we have a custom color scheme.
	$colors = array(
		'background_color'                                    => $color_scheme[0],
		'header_textcolor'                                    => $color_scheme[1],
		'page_background_color'                               => $color_scheme[2],
		'secondary_background_color'                          => $color_scheme[3],
		'absolute_header_background_color'                    => $color_scheme[4],
		'main_text_color'                                     => $color_scheme[5],
		'headline_text_color'                                 => $color_scheme[6],
		'headline_text_color_eighty_nine_color'               => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.89)', $headline_text_color_rgb ),
		'tertiary_background'                                 => $color_scheme[7],
		'ninety_of_tertiary_background'                       => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.9)', $tertiary_background_rgb ),
		'link_color'                                          => $color_scheme[8],
		'eighty_six_of_link_color'                            => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.86)', $link_color_rgb ),
		'link_hover_color'                                    => $color_scheme[9],
		'secondary_link_color'                                => $color_scheme[10],
		'button_background_color'                       	  => $color_scheme[11],
		'button_text_color'                                   => $color_scheme[12],
		'tertiary_link_color'                                 => $color_scheme[13],
		'button_hover_text_color'                             => $color_scheme[14],
		'button_background_hover_color'                       => $color_scheme[15],
		'blog_background_odd'                                 => $color_scheme[16],
		'blog_background_even'                                => $color_scheme[17],
		'blog_background_even_color'                          => $color_scheme[18],
		'border_color'                                        => $color_scheme[19],
		'border_color_ninety_nine_color'                      => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.99)', $border_color_rgb ),
		'textcolor_with_background'                           => $color_scheme[20],
		'textcolor_with_background_eighty_two_color'          => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.82)', $textcolor_with_background_rgb ),
		'team_section_title_color'                            => $color_scheme[21],
	);

	$color_scheme_css = signify_get_color_scheme_css( $colors );

	wp_add_inline_style( 'signify-block-style', $color_scheme_css );
}
add_action( 'wp_enqueue_scripts', 'signify_color_scheme_css' );

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since 1.0.0
 */
function signify_customize_control_js() {
	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
	
	wp_enqueue_script( 'signify-color-scheme-control', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'js/color-scheme-control' . $min . '.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20170816', true );

	$colors['colorScheme'] = signify_get_color_schemes();

	$color_options = signify_color_options();

	// Add background color and header text color index values
	$color_options = array_merge( array( 'background_color', 'header_textcolor' ), array_keys( $color_options ) );

	$colors['colorOptions'] = $color_options;

	wp_localize_script( 'signify-color-scheme-control', 'signifyColorMain', $colors );

	wp_enqueue_script( 'signify-custom-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'js/customize-custom-controls' . $min . '.js', array( 'jquery-ui-sortable' ), '20180802', true );

	wp_enqueue_style( 'signify-custom-controls-css', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'css/customizer.css' );

}
add_action( 'customize_controls_enqueue_scripts', 'signify_customize_control_js' );

/**
 * Returns CSS for the color schemes.
 *
 * @since 1.0.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function signify_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'background_color'                                    => '',
		'header_textcolor'                                    => '',
		'page_background_color'                               => '',
		'secondary_background_color'                          => '',
		'absolute_header_background_color'                    => '',
		'main_text_color'                                     => '',
		'headline_text_color'                                 => '',
		'headline_text_color_eighty_nine_color'               => '',
		'tertiary_background'                                 => '',
		'ninety_of_tertiary_background'                       => '',
		'link_color'                                          => '',
		'eighty_six_of_link_color'                            => '',
		'link_hover_color'                                    => '',
		'secondary_link_color'                                => '',
		'button_background_color'                             => '',
		'button_text_color'                                   => '',
		'tertiary_link_color'                                 => '',
		'button_hover_text_color'                             => '',
		'button_background_hover_color'                       => '',
		'blog_background_odd'                                 => '',
		'blog_background_even'                                => '',
		'blog_background_even_color'                          => '',
		'border_color'                                        => '',
		'border_color_ninety_nine_color'                      => '',
		'textcolor_with_background'                           => '',
		'textcolor_with_background_eighty_two_color'          => '',
		'team_section_title_color'                            => '',

	) );

	return <<<CSS
	/* Color Scheme */

	/* Background Color */
	body {
		background-color: {$colors['background_color']};
	}

	/* Page Background Color */
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
	select,
	.select2-container--default .select2-selection--single,
	.screen-reader-text:focus,
	.team-section .team-content-wrapper .hentry .entry-container:before,
	.boxed-layout .site,
	.ui-state-active,
	.site-header-cart .cart-contents .count,
	.ui-widget-content .ui-state-active,
	.ui-widget-header .ui-state-active,
	#colophon #site-generator,
	.onsale,
	#contact-section,
	#contact-section .contact-content-wrapper,
	.comments-area input[type="text"],
	.comments-area input[type="email"],
	.comments-area input[type="url"],
	.comments-area input[type="password"],
	.comments-area input[type="search"],
	.comments-area input[type="number"],
	.comments-area input[type="tel"],
	.comments-area input[type="range"],
	.comments-area input[type="date"],
	.comments-area input[type="month"],
	.comments-area input[type="week"],
	.comments-area input[type="time"],
	.comments-area input[type="datetime"],
	.comments-area input[type="datetime-local"],
	.comments-area input[type="color"],
	.comments-area textarea {
		background-color: {$colors['page_background_color']};
	}

	.wp-playlist-light, #sticky-playlist-section, 
	#sticky-playlist-section .wp-playlist-tracks {
	    background-color: {$colors['page_background_color']};
	}

	/* Secondary Background Color */
	#colophon .widget-area,
	.section:nth-child(odd),
	.mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-total, 
	.mejs-controls .mejs-time-rail .mejs-time-total,
	.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-loaded, 
	.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-float,
	ins,
	.sidebar .widget-wrap,
	#primary-search-wrapper .menu-inside-wrapper,
	.menu-inside-wrapper,
	.mobile-social-search,
	#footer-newsletter,
	mark,
	ins,
	.custom-header,
	ul.tabs.wc-tabs li.active a,
	.woocommerce-Tabs-panel,
	.shop_table thead th,
	ul.wc_payment_methods.payment_methods.methods li,
	.comment-respond,
	.widget_shopping_cart,
	pre,
	.widget .ui-tabs .ui-tabs-panel,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	textarea,
	.header-top-bar,
	.comment-list .comment .comment-container {
		background-color: {$colors['secondary_background_color']};
	}

	#sticky-playlist-section {
	    border-color: {$colors['secondary_background_color']};
	}

	@media screen and (min-width: 1024px) {
	    .navigation-classic .site-header .sub-menu,
	    .navigation-classic .site-header .children {
	        background-color: {$colors['secondary_background_color']};
	    }
	}

	/* Absolute Header Background Color for Inner Pages */
	.site-header {
		background-color: {$colors['absolute_header_background_color']};
	}

	/* Main Text Color */
	body,
	input,
	select,
	optgroup,
	textarea,
	table a,
	input::placeholder,
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	blockquote,
	#promotion-section .play-video .play-button:hover:before,
	#promotion-section .play-video .play-button:focus:before,
	.entry-container .entry-content,
	.entry-container .entry-summary {
		color: {$colors['main_text_color']};
	}

	/* Header Text Color */
	.site-title a,
	.site-description {
		color: {$colors['header_textcolor']};
	}

	/* Headline Text Color */
	h1,
	h2,
	h3,
	h4,
	h5,
	h6,
	#product-content-section  .product-container a.button,
	.author-name,
	.comment-reply-link,
	.author-title,
	.comment-respond .comment-form p label {
		color: {$colors['headline_text_color']};
	}

	@media and (min-width: 768px) {
	    .testimonials-content-wrapper.section.testimonial-wrapper .cycle-pager span { 
	        color: {$colors['headline_text_color']};
	    }
	}

	/* 89% of heading color */

	.section-title,
	.portfolio-section-headline .section-title,
	.entry-title a,
	.drop-cap:first-letter,
	.vcard,
	.position,
	.entry-meta a,
	.section-description-wrapper,
	.section-title-wrapper+.section-description,
	.section-title+.section-description,
	.section-title-wrapper+.section-subtitle,
	.section-heading-wrapper>.section-description,
	.section-title+.section-description,
	.section-heading-wrapper>.section-subtitle {
	    color: {$colors['headline_text_color_eighty_nine_color']};
	}	

	/* Tertiary Background Color */
	#colophon,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button,
	.team-content-wrapper .entry-container,
	.playlist-content-wrapper .wp-playlist,
	#gallery-section .gallery-item .gallery-icon a:before,
	#gallery-section .tiled-gallery .tiled-gallery-item a:before,
	.app-section .entry-container:after,
	.playlist-content-wrapper .wp-playlist .wp-playlist-tracks > div:hover,
	.playlist-content-wrapper .wp-playlist .wp-playlist-tracks > div:focus {
	    background-color: {$colors['tertiary_background']};
	}

	.team-content-wrapper .entry-content:before,
	.team-content-wrapper .entry-summary:before {
	    background-image: linear-gradient(to bottom, {$colors['ninety_of_tertiary_background']}, {$colors['tertiary_background']});
	}

	/* Link Color */
	a,
	.sidebar .widget-wrap p,
	.sidebar .widget-wrap li a,
	.custom-header-content .site-header-text .entry-meta a:hover,
	.custom-header-content .site-header-text .entry-meta a:focus,
	.dropdown-toggle,
	.site-header-menu .menu-inside-wrapper .nav-menu li button,
	.ui-state-active a,
	.ui-state-active a:link,
	.ui-state-active a:visited,
	.social-search-wrapper .menu-social-container li a,
	.menu-social-container a,
	.sidebar nav.social-navigation ul li a:hover,
	.sidebar nav.social-navigation ul li a:focus,
	.screen-reader-text:focus,
	td#today,
	.toggled-on.active:before,
	.comment-respond .comment-form p.is-focused label,
	.contact-section.section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li a {
		color: {$colors['link_color']};
	}

	/* 86% of link color */

	.nav-title,
	.post-title,
	.comments-title,
	.comment-reply-title,
	.woocommerce.has-header-image .woocommerce-breadcrumb a:hover,
	.woocommerce.has-header-image .woocommerce-breadcrumb a:focus,
	span.breadcrumb a:hover,
	span.breadcrumb a:focus,
	.widget_recent_entries li a {
	   color: {$colors['eighty_six_of_link_color']};
	}


	/* Link Hover Color */

	p.stars:hover a:before,
	p.stars:focus a:before,
	.star-rating span:before,
	p.stars.selected a.active:before,
	p.stars.selected a:not(.active):before,
	p.stars.selected a.active~a:before,
	p.stars a:hover~a:before,
	p.stars a:focus~a:before,
	.site-header-cart .cart-contents:hover .count,
	.site-header-cart .cart-contents:focus .count,
	.page-numbers.current,
	.page-links .current,
	#site-header-cart-wrapper a.cart-contents .count,
	.menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a,
	#reviews .comment-respond .comment-form-rating .stars span a.active:before,
	#reviews .comment-respond .comment-form-rating .stars.selected span a:not(.active):before {
		color: {$colors['link_hover_color']};
	} 

	a:hover,
	a:focus,
	.site-info a:hover,
	.site-info a:focus,
	.post-title:hover,
	.post-title:focus,
	.site-title a:hover,
	.site-title a:focus,
	.play-button-text:hover,
	.play-button-text:focus,
	.woocommerce .woocommerce-breadcrumb a:hover,
	.woocommerce .woocommerce-breadcrumb a:focus,
	.has-background-image .woocommerce-loop-product__title:hover,
	.has-background-image .woocommerce-loop-product__title:focus,
	.has-background-image  .entry-container .entry-meta a:hover,
	.has-background-image  .entry-container .entry-meta a:focus,
	.has-background-image  .entry-container .entry-title a:hover,
	.has-background-image  .entry-container .entry-title a:focus,
	#testimonial-content-section .owl-prev:hover, 
	#testimonial-content-section .owl-prev:focus, 
	#testimonial-content-section .owl-next:hover,
	#testimonial-content-section .owl-next:focus,
	.single footer .entry-meta a:hover,
	.single footer .entry-meta a:focus,
	#site-footer-navigation li a:hover,
	#site-footer-navigation li a:focus,
	#social-footer-navigation li a:hover,
	#social-footer-navigation li a:focus,
	.has-background-image .entry-title a:hover,
	.has-background-image .entry-title a:focus,
	.has-background-image .entry-meta a:hover,
	.has-background-image .entry-meta a:focus,
	.archive-post-wrap .hentry:nth-child(2n) .entry-title a:hover,
	.archive-post-wrap .hentry:nth-child(2n) .entry-title a:focus,
	.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:hover,
	.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:focus,
	.team-content-wrapper .entry-container .entry-title a:hover,
	.team-content-wrapper .entry-container .entry-title a:focus,
	.team-content-wrapper .entry-container .entry-meta a:hover,
	.team-content-wrapper .entry-container .entry-meta a:focus,
	.team-content-wrapper .entry-container .social-navigation a:hover,
	.team-content-wrapper .entry-container .social-navigation a:focus,
	.wp-playlist-tracks .wp-playlist-caption:hover,
	.wp-playlist-tracks .wp-playlist-caption:focus,
	.signify-mejs-container.mejs-container button:hover,
	.signify-mejs-container.mejs-container button:focus,
	#service-section .entry-title a:hover,
	#service-section .entry-title a:focus,
	.woocommerce-loop-product__title:hover,
	.woocommerce-loop-product__title:focus,
	span.price span.woocommerce-Price-amount:hover,
	span.price span.woocommerce-Price-amount:focus,
	.events-content-wrapper .entry-meta a:hover,
	.events-content-wrapper .entry-meta a:focus,
	.widget_recent_entries li a:hover,
	.widget_recent_entries li a:focus,
	.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:hover,
	.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:focus,
	button.dropdown-toggle:hover,
	button.dropdown-toggle:focus,
	.site-header-menu .menu-inside-wrapper .nav-menu li button:hover,
	.site-header-menu .menu-inside-wrapper .nav-menu li button:focus,
	.portfolio-content-wrapper .hentry .entry-container a:hover,
	.portfolio-content-wrapper .hentry .entry-container a:focus,
	button#wp-custom-header-video-button:hover,
	button#wp-custom-header-video-button:focus,
	.widget .ui-state-default a:hover,
	.widget .ui-state-default a:focus,
	.widget .ui-widget-content .ui-state-default a:hover,
	.widget .ui-widget-content .ui-state-default a:focus,
	.widget .ui-widget-header .ui-state-default a:hover,
	.widget .ui-widget-header .ui-state-default a:focus,
	body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:hover,
	body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:focus,
	.tag-cloud-link:hover,
	.tag-cloud-link:focus,
	.nav-title:hover,
	.nav-title:focus,
	.menu-social-container a:hover,
	.menu-social-container a:focus,
	.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:hover,
	.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:focus,
	.portfolio-content-wrapper .hentry .entry-container a:hover,
	.portfolio-content-wrapper .hentry .entry-container a:focus,
	.portfolio-content-wrapper .hentry .entry-container .entry-meta time:hover,
	.portfolio-content-wrapper .hentry .entry-container .entry-meta time:focus,
	.social-search-wrapper .menu-social-container li a:hover,
	.social-search-wrapper .menu-social-container li a:focus,
	.sidebar .widget-wrap .more-link:hover,
	.sidebar .widget-wrap .more-link:focus,
	.author a:hover,
	.author a:focus,
	.entry-meta a:hover,
	.entry-meta a:focus,
	.entry-title a:hover,
	.entry-title a:focus,
	.site-footer td#prev a:hover,
	.site-footer td#prev a:focus,
	.site-footer td#next a:hover,
	.site-footer td#next a:focus,
	.comment-reply-link:hover,
	.comment-reply-link:focus,
	aside.footer-widget-area a:hover,
	aside.footer-widget-area a:focus,
	.author-section-title:hover,
	.author-section-title:focus,
	.comment-permalink:hover,
	.comment-permalink:focus,
	.comment-edit-link:hover,
	.comment-edit-link:focus,
	.nav-subtitle:hover,
	.nav-subtitle:focus,
	.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:hover,
	.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:focus,
	#site-generator .menu-social-container a:hover,
	#site-generator .menu-social-container a:focus,
	.widget-wrap li a:hover,
	.widget-wrap li a:focus,
	.main-navigation ul:not(.sub-menu)>li>a:hover,
	.main-navigation ul:not(.sub-menu)>li>a:focus,
	.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:hover,
	.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:focus,
	#site-header-cart-wrapper a.cart-contents:hover,
	#site-header-cart-wrapper a.cart-contents:focus,
	.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:hover,
	.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:focus,
	#featured-content-section .section-content-wrapper .hentry .more-link:hover,
	#featured-content-section .section-content-wrapper .hentry .more-link:focus,
	.service-section .hentry .more-link:hover,
	.service-section .hentry .more-link:focus,
	#portfolio-content-section .hentry .more-link:hover,
	#portfolio-content-section .hentry .more-link:focus,
	#service-section .hentry .more-link:hover,
	#service-section .hentry .more-link:focus,
	#stats-section .hentry .more-link:hover,
	#stats-section .hentry .more-link:focus,
	#service-section.has-background-image .hentry .more-link:hover,
	#service-section.has-background-image .hentry .more-link:focus,
	#stats-section.has-background-image .hentry .more-link:hover,
	#stats-section.has-background-image  .hentry.more-link:focus,
	.navigation.pagination a:hover,
	.navigation.pagination a:focus,
	.playlist-content-wrapper .signify-mejs-container.mejs-container button:hover,
	.playlist-content-wrapper .signify-mejs-container.mejs-container button:focus {
		color: {$colors['link_hover_color']};
	}



	/* Secondary Link Color */
	ins,
	.entry-breadcrumbs a,
	.woocommerce.woocommerce-active .woocommerce-breadcrumb a,
	p.stars a,
	.single footer .entry-meta a,
	p.stars a:before,
	.controller:before,
	.tag-cloud-link,
	.select2-results__option,
	body.no-header-media-image .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu .current_page_item > a,
	#footer-newsletter .wrapper .section-description,
	.widget-wrap span.post-date,
	.contact-section .entry-container a,
	.archive .section-content-wrapper .more-link .readmore,
	.featured-content-section .hentry .more-link,
	.faq-section .hentry .more-link,
	.team-section .hentry .more-link,
	.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:before,
	.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:after,
	.testimonials-content-wrapper.section.testimonial-wrapper .cycle-next:before,
	.clients-content-wrapper .controller .cycle-pager span,
	.testimonials-content-wrapper .cycle-pager:after,
	.slider-content-wrapper .entry-container .entry-container-wrap .entry-summary,
	.portfolio-content-wrapper .filter-button-group button,
	.testimonials-content-wrapper .entry-title a,
	.testimonials-content-wrapper.section.testimonial-wrapper .hentry,
	.scrollup a:hover:before,
	.scrollup a:focus:before,
	.sidebar .widget-wrap .more-link,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
	.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a,
	.team-section .entry-meta,
	.author-label,
	.entry-title .sub-title,
	.section-heading-wrapper .entry-title .sub-title,
	.section-heading-wrapper .entry-title span,
	.author-section-title,
	.comment-permalink,
	.comment-edit-link,
	.entry-title span,
	.nav-subtitle,
	.nav-menu .menu-item-has-children>a:before,
	.nav-menu .menu_item_has_children>a:before,
	input,
	select,
	optgroup,
	textarea,
	aside.footer-widget-area .widget,
	aside.footer-widget-area svg,
	aside.footer-widget-area a,
	.site-info,
	.playlist-content-wrapper .mejs-time,
	span.woocommerce-Price-amount,
	.catch-breadcrumb.center .entry-breadcrumbs, 
	.catch-breadcrumb.center .woocommerce-breadcrumb {
		color: {$colors['secondary_link_color']};
	}

	/* Button Background Color */

	.more-link,
	.button,
	.onsale,
	.entry-content button,
	.entry-summary button,
	button,
	#scrollup,
	.slider-content-wrapper .controllers .cycle-prev,
	.slider-content-wrapper .controllers .cycle-next,
	input[type="submit"],
	button[type="submit"],
	.scrollup a,
	.sticky-post,
	#team-dots li.active:after,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus,
	.wp-block-button__link,
	#infinite-handle .ctis-load-more button,
	.menu-inside-wrapper #site-header-cart-wrappe li>a,
	.contact-section .entry-container ul.contact-details li .fa,
	nav.navigation.posts-navigation .nav-links a,
	.woocommerce-pagination ul.page-numbers li .page-numbers.current,
	.archive-content-wrap .pagination .page-numbers.current,
	.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
	.catch-instagram-feed-gallery-widget-wrapper .button,
	#signify-logo-slider-section .owl-dots .owl-dot span,
	#signify-logo-slider-section .owl-prev,
	#signify-logo-slider-section .owl-next, 
	.sticky-label {
	    background-color: {$colors['button_background_color']};
	}

	blockquote,
	#signify-logo-slider-section .owl-prev:hover,
	#signify-logo-slider-section .owl-prev:focus,
	#signify-logo-slider-section .owl-next:hover, 
	#signify-logo-slider-section .owl-next:focus, 
	#signify-logo-slider-section .owl-dots .owl-dot.active span,
	.woocommerce .products .product-container .button {
	    border-color: {$colors['button_background_color']};
	}

	/* Button Text Color */

	.more-link,
	.onsale,
	#scrollup,
	.entry-content button,
	.entry-summary button,
	.slider-content-wrapper .controllers .cycle-prev,
	.slider-content-wrapper .controllers .cycle-next,
	button,
	#primary-search-wrapper .search-container button,
	input[type="submit"],
	.button,
	.scroll-down,
	.scrollup a:before,
	.page-numbers:hover,
	.page-numbers:focus,
	button[type="submit"],
	button#wp-custom-header-video-button,
	#infinite-handle .ctis-load-more button,
	nav.navigation.posts-navigation .nav-links a,
	.woocommerce-pagination ul.page-numbers li:hover,
	.archive-content-wrap .pagination .page-numbers:hover,
	.archive-content-wrap .pagination .page-numbers:focus,
	.woocommerce-pagination ul.page-numbers li:focus,
	.archive-content-wrap .pagination .page-numbers.current,
	.woocommerce-pagination ul.page-numbers li .page-numbers.current,
	#portfolio-content-section .entry-container,
	.contact-details li .fa,
	.slider-content-wrapper #featured-slider-prev:hover:before,
	.slider-content-wrapper #featured-slider-next:hover:before,
	.slider-content-wrapper #featured-slider-prev:focus:before,
	.slider-content-wrapper #featured-slider-next:focus:before,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover:before,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus:before,
	.nav-menu .menu-item-has-children>a:hover:before,
	.nav-menu .menu-item-has-children>a:focus:before,
	.nav-menu .menu_item_has_children>a:hover:before,
	.nav-menu .menu_item_has_children>a:focus:before,
	.contact-section .entry-container ul.contact-details li .fa,
	.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover a,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus a {
	    color: {$colors['button_text_color']};
	}

	/* Header and Tertiary Color*/ 

	.feature-slider-wrapper .entry-container .entry-title,
	.feature-slider-wrapper .entry-container .entry-title span,
	.feature-slider-wrapper .entry-container .entry-summary p,
	.feature-slider-wrapper .entry-container .entry-content p,
	.custom-header-content .site-header-text,
	.custom-header-content .site-header-text .entry-meta a,
	.custom-header-content-wrapper .section-title,
	.signify-mejs-container.mejs-container button,
	.wp-playlist-current-item,
	.mejs-time,
	.navigation-classic .main-navigation .nav-menu > li >a,
	.navigation-classic button.menu-toggle,
	#site-header-cart-wrapper a.cart-contents,
	.menu-toggle,
	.menu-label,
	.section .owl-carousel .owl-nav button.owl-next, 
	.section .owl-carousel .owl-nav button.owl-prev {
	    color: {$colors['tertiary_link_color']};
	}

	@media and (min-width: 1200px) {
	.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:hover, 
	.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:focus {
           color: {$colors['tertiary_link_color']};
        }
    }

    .menu-toggle:hover .menu-label,
    .menu-toggle:focus .menu-label,
    .menu-toggle:hover:before,
    .menu-toggle:focus:before {
        color: {$colors['tertiary_link_color']};
    }

    @media screen and (min-width: 768px) {
    	.has-header-image #site-header-cart-wrapper a.cart-contents:hover, 
		.has-header-image #site-header-cart-wrapper a.cart-contents:focus,
		.absolute-header button.menu-toggle:hover,
		.absolute-header button.menu-toggle:focus
	   	#site-header-cart-wrapper a.cart-contents:hover,
		#site-header-cart-wrapper a.cart-contents:focus {
            color: {$colors['tertiary_link_color']};
        }
    }

	.owl-carousel .owl-dots button.owl-dot span,
	#feature-slider-section .owl-nav button:hover,
	#feature-slider-section .owl-nav button:focus {
	    background-color: {$colors['tertiary_link_color']}
	}

	.owl-carousel .owl-dots button.owl-dot.active span {
	    border-color: {$colors['tertiary_link_color']};
	}

	/* Button Hover Text Color */

	.more-link:hover,
	.more-link:focus,
	button:hover,
	button:focus,
	.site-title a:hover,
	.site-title a:focus,
	#signify-logo-slider-section .owl-prev:hover,
	#signify-logo-slider-section .owl-prev:focus,
	#signify-logo-slider-section .owl-next:hover, 
	#signify-logo-slider-section .owl-next:focus, 
	.button:hover,
	.button:focus,
	.entry-content button:hover,
	.entry-content button:focus,
	.entry-summary button:hover,
	.entry-summary button:focus,
	#social-search-toggle svg:hover,
	#social-search-toggle svg:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	button[type="submit"]:hover,
	button[type="submit"]:focus,
	#primary-search-wrapper .search-container button:hover,
	#primary-search-wrapper .search-container button:focus,
	#infinite-handle .ctis-load-more button:hover,
	#infinite-handle .ctis-load-more button:focus,
	nav.navigation.posts-navigation .nav-links a:hover,
	nav.navigation.posts-navigation .nav-links a:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
	.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.feature-slider-wrapper .entry-summary a:hover,
	.feature-slider-wrapper .entry-summary a:focus,
	#contact-section input[type="submit"]:hover,
	#contact-section input[type="submit"]:focus,
	.has-header-image .custom-header-content .more-link:hover,
	.has-header-image .custom-header-content .more-link:focus,
	.has-header-image .site-title a:hover,
	.has-header-image .site-title a:focus,
	#product-content-section .product-container a.button:hover,
	#product-content-section .product-container a.button:focus,
	#scrollup:hover,
	#scrollup:focus {
	    color: {$colors['button_hover_text_color']};
	}

    #menu-toggle:hover .menu-label,
	#menu-toggle:focus .menu-label,
	#menu-toggle:hover:before,
	#menu-toggle:focus:before,
	.scrollup a:hover:before,
	.scrollup a:focus:before,
	.menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a {
	    color: {$colors['button_hover_text_color']};
	}

	/* Button Hover Background Color */

	.more-link:hover,
	.more-link:focus,
	#contact-section.has-background-image input[type="submit"]:hover,
	#contact-section.has-background-image input[type="submit"]:focus,
	.button:hover,
	.button:focus,
	#scrollup:hover,
	#scrollup:focus,
	#signify-logo-slider-section .owl-prev:hover,
	#signify-logo-slider-section .owl-prev:focus,
	#signify-logo-slider-section .owl-next:hover, 
	#signify-logo-slider-section .owl-next:focus,
	button:hover, 
	button:focus, 
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	button[type="submit"]:hover,
	button[type="submit"]:focus,
	.wp-block-button__link:hover,
	.wp-block-button__link:focus,
	.woocommerce .products .product-container .button:hover,
	.woocommerce .products .product-container .button:focus,
	#infinite-handle .ctis-load-more button:hover,
	#infinite-handle .ctis-load-more button:focus,
	.slider-content-wrapper .cycle-next:hover,
	.slider-content-wrapper .cycle-next:focus,
	.slider-content-wrapper .cycle-prev:hover,
	.slider-content-wrapper .cycle-prev:focus,
	nav.navigation.posts-navigation .nav-links a:hover,
	nav.navigation.posts-navigation .nav-links a:focus,
	.woocommerce-pagination ul.page-numbers li .page-numbers:hover,
	.woocommerce-pagination ul.page-numbers li .page-numbers:focus,
	.archive-content-wrap .pagination .page-numbers:hover,
	.archive-content-wrap .pagination .page-numbers:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.feature-slider-wrapper .entry-summary a:hover,
	.feature-slider-wrapper .entry-summary a:focus,
	#contact-section input[type="submit"]:hover,
	#contact-section input[type="submit"]:focus,
	.has-header-image .custom-header-content .more-link:hover,
	.has-header-image .custom-header-content .more-link:focus,
	#feature-slider-section .more-link:hover,
	#feature-slider-section .more-link:focus {
        background-color: {$colors['button_background_hover_color']};
    }

	#signify-logo-slider-section {
	    background-color: {$colors['button_background_hover_color']};
	}

	/* blog background Odd */
	.archive-post-wrap .hentry {
	    background-color: {$colors['blog_background_odd']};
	}

	/* blog background Even */
	.archive-post-wrap .hentry:nth-child(2n) {
	    background-color: {$colors['blog_background_even']};
	}

	/* blog background Even Color */
	.archive-post-wrap .hentry:nth-child(2n) .entry-title a,
	.archive-post-wrap .hentry:nth-child(2n) .entry-meta a,
	.archive-post-wrap .hentry:nth-child(2n) .entry-summary p,
	.archive-post-wrap .hentry:nth-child(2n) .entry-content p {
	    color: {$colors['blog_background_even_color']};
	}

	/* Border Color */
	nav.navigation,
	.site-content .archive-posts-wrapper .posts-navigation .nav-links .nav-previous,
	.woocommerce-tabs .panel,
	#signify-logo-slider-section .owl-prev,
	#signify-logo-slider-section .owl-next,
	.woocommerce-tabs ul.tabs li.active a:after,
	.woocommerce-tabs ul.tabs:after,
	.calendar_wrap tbody tr:first-child,
	.calendar_wrap tbody tr:last-child,
	tfoot,
	tfoot tr td,
	.author-info,
	.wpcf7 div input, 
	.wpcf7 div textarea,
	#promotion-section .play-button,
	.navigation-classic .main-navigation ul ul,
	.woocommerce-shorting-wrapper,
	.woocommerce-tabs ul.tabs.wc-tabs li,
	.menu-wrapper .widget_shopping_cart ul.woocommerce-mini-cart li,
	.entry-summary form.cart,
	.widget_recent_entries li,
	.team-section .team-content-wrapper .hentry .team-social-profile .social-links-menu,
	input[type="submit"],
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="number"],
	input[type="tel"],
	input[type="range"],
	input[type="date"],
	input[type="month"],
	input[type="week"],
	input[type="time"],
	input[type="datetime"],
	input[type="datetime-local"],
	input[type="color"],
	textarea,
	table,
	caption,
	.sidebar.widget-area .widget-wrap,
	table th,
	table thead tr,
	table thead th,
	thead th,
	tbody th,
	tbody td,
	tbody tr,
	table.shop_table_responsive tr td,
	table tbody tr,
	table.shop_table_responsive tbody tr:last-child,
	.shop_table tfoot tr td,
	.shop_table tfoot tr th,
	table.shop_table.woocommerce-checkout-review-order-table .cart_item td,
	table.shop_table.woocommerce-checkout-review-order-table tr td,
	table.shop_table.woocommerce-checkout-review-order-table tr th,
	.rtl tbody td:last-child,
	.rtl table thead th:last-child,
	.select2-container--default .select2-selection--single,
	table.woocommerce-grouped-product-list.group_table,
	table.woocommerce-grouped-product-list.group_table td,
	table.variations,
	table.variations td,
	.woocommerce-pagination ul.page-numbers li .page-numbers,
	.archive-content-wrap .navigation.pagination .page-numbers,
	.woocommerce-posts-wrapper .summary.entry-summary .woocommerce-product-rating,
	.cart-collaterals .order-total,
	#payment .wc_payment_methods .payment_box,
	.products .product,
	select,
	header .site-header-main,
	abbr,
	acronym,
	.product-quantity input[type="number"],
	.coupon input[type="text"],
	.site-header-main .menu-inside-wrapper,
	.catch-instagram-feed-gallery-widget-wrapper .button,
	.site-header-cart .widget_shopping_cart,
	.woocommerce-grouped-product-list tr,
	.mobile-social-search,
	.widget .ui-tabs .ui-tabs-panel,
	.site-header-menu .menu-inside-wrapper .nav-menu button:focus,
	header .site-header-menu .menu-inside-wrapper .main-navigation .sub-menu li:last-child,
	header .site-header-menu .menu-inside-wrapper .main-navigation .children li:last-child,
	.comment-body,
	.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link,
	.section:nth-child(2n) + .site-content,
	.archive-content-wrap .section-content-wrapper.layout-one .hentry .hentry-inner .entry-container>.entry-meta,
	.comments-area,
	.playlist-content-wrapper .wp-playlist .wp-playlist-tracks {
		border-color: {$colors['border_color']};
	}

	/* 99% of border color*/
	.page .site-main .entry-footer .entry-meta > span:not(.edit-link),
	.single .site-main .entry-footer .entry-meta > span:not(.edit-link),
	.events-content-wrapper .hentry,
	.tagcloud a,
	textarea:focus,
	input[type="text"]:focus,
	input[type="email"]:focus,
	input[type="url"]:focus,
	input[type="password"]:focus,
	input[type="search"]:focus,
	input[type="number"]:focus,
	input[type="tel"]:focus,
	input[type="range"]:focus,
	input[type="date"]:focus,
	input[type="month"]:focus,
	input[type="week"]:focus,
	input[type="time"]:focus,
	input[type="datetime"]:focus,
	input[type="datetime-local"]:focus,
	input[type="color"]:focus,
	.wpcf7 div input:focus, 
	.wpcf7 div textarea:focus {
	    border-color: {$colors['border_color_ninety_nine_color']};
	}

	/* Text Color With Background color */
	.scroll-down,
	.site-info a,
	.job-label,
	.has-background-image input[type="text"],
	.has-background-image input[type="email"],
	.has-background-image input[type="url"],
	.has-background-image input[type="password"],
	.has-background-image input[type="search"],
	.has-background-image input[type="number"],
	.has-background-image input[type="tel"],
	.has-background-image input[type="range"],
	.has-background-image input[type="date"],
	.has-background-image input[type="month"],
	.has-background-image input[type="week"],
	.has-background-image input[type="time"],
	.has-background-image input[type="datetime"],
	.has-background-image input[type="datetime-local"],
	.has-background-image input[type="color"],
	.has-background-image textarea,
	.has-background-image select,
	.play-button-text,
	.custom-header .entry-breadcrumbs a,
	.woocommerce .custom-header .woocommerce-breadcrumb a,
	.has-header-image .custom-header .catch-breadcrumb .entry-breadcrumbs, 
	.has-header-image .custom-header .catch-breadcrumb .woocommerce-breadcrumb,
	aside.footer-widget-area a,
	.team-content-wrapper .owl-prev:before,
	.team-content-wrapper .owl-next:before,
	#team-content-section .team-content-wrapper.owl-carousel .owl-nav button.disabled,
	.team-content-wrapper .entry-container .entry-title a,
	.team-content-wrapper .entry-container .entry-header,
	.team-content-wrapper .entry-container .entry-meta a,
	.team-content-wrapper .entry-container .entry-summary p,
	.team-content-wrapper .entry-container .entry-content p,
	.team-content-wrapper .entry-container .social-navigation a,
	.custom-header-content .entry-title .sub-title,
	#signify-logo-slider-section .entry-summary p,
	#signify-logo-slider-section .entry-title span, 
	.hero-content-wrapper.has-background-image .entry-container,
	.portfolio-content-wrapper .hentry .entry-container a,
	.portfolio-content-wrapper .hentry .entry-container .entry-meta time,
	.portfolio-content-wrapper .hentry .entry-container .entry-summary,
	.custom-header-content .entry-container,
	.custom-header-content .entry-container .entry-title,
	.ewnewsletter.has-background-image .section-title,
	.ewnewsletter.has-background-image .section-title,
	.site-footer .widget-wrap .widget-title,
	.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .hentry,
	.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .position,
	.slider-content-wrapper.content-frame .entry-container .entry-title a,
	.slider-content-wrapper.content-frame .entry-container .entry-container-wrap .entry-summary,
	aside.footer-widget-area .widget-title,
	.playlist-content-wrapper .signify-mejs-container.mejs-container button,
	.playlist-content-wrapper .wp-playlist-current-item,
	.has-background-image .section-title,
	#contact-section.has-background-image .hentry,
	#contact-section.has-background-image .entry-title,
	.has-background-image  .entry-container .entry-meta a,
	.has-background-image  .entry-container .entry-title a,
	.has-background-image  .entry-container .entry-title,
	.has-background-image  .entry-container .entry-title span,
	.has-background-image  .entry-container .entry-summary,
	.has-background-image  .entry-container .entry-summary p,
	.has-background-image  .entry-container .entry-content,
	.has-background-image  .entry-container .entry-content p,
	.content-color-white .entry-container .entry-title a,
	.content-color-white .entry-container .entry-title,
	.content-color-white .entry-container .entry-content p,
	.content-color-white .entry-container .entry-summary p,
	.has-background-image .woocommerce-loop-product__title,
	#promotion-section .play-button,
	.has-background-image .products .button,
	#feature-slider-section .owl-nav button:hover:before,
	#feature-slider-section .owl-nav button:focus:before,
	#service-section.has-background-image .hentry .more-link,
	#stats-section.has-background-image .hentry .more-link,
	.playlist-content-wrapper .wp-playlist-caption {
	    color: {$colors['textcolor_with_background']};  
	}

	.feature-slider-wrapper .entry-summary a,
	.feature-slider-wrapper .entry-content a,
	.feature-slider-wrapper a.more-link,
	.has-header-image .custom-header-content .entry-summary a,
	.has-header-image .custom-header-content .entry-content a,
	.has-header-image .custom-header-content a.more-link,
	#contact-section.has-background-image input[type="submit"],
	#promotion-section .play-video .play-button:hover,
	#promotion-section .play-video .play-button:focus {
		background-color: {$colors['textcolor_with_background']};
	}

	/* 82% of text color with background */

	.has-background-image .event-list-description .entry-summary,
	.has-background-image .event-list-description .entry-summary  p,
	.has-background-image .event-list-description .entry-content,
	.has-background-image .event-list-description .entry-content  p,
	#contact-section.has-background-image .entry-content p,
	#contact-section.has-background-image .entry-summary p,
	.playlist-content-wrapper .wp-playlist-tracks,
	#social-footer-navigation li a,
	#site-footer-navigation li a,
	.footer-contact,
	#contact-section .entry-container .entry-content .contact-details label,
	#contact-section .entry-container .entry-summary .contact-details label,
	.has-background-image .section-description-wrapper,
	.has-background-image .section-title-wrapper+.section-description,
	.has-background-image .section-title+.section-description,
	.has-background-image .section-title-wrapper+.section-subtitle,
	.has-background-image .section-heading-wrapper>.section-description,
	.has-background-image .section-title+.section-description,
	.has-background-image .section-heading-wrapper>.section-subtitle {
	    color: {$colors['textcolor_with_background_eighty_two_color']};
	}

	/* Team Section title color */

	#team-content-section .section-title {
	    color: {$colors['team_section_title_color']};
	}

CSS;
}


/**
 * Outputs an Underscore template for generating CSS for the color scheme.
 *
 * The template generates the css dynamically for instant display in the
 * Customizer preview.
 *
 * @since 1.0.0
 */
function signify_color_scheme_css_template() {
	$colors = array(
	'background_color'                                    => '{{ data.background_color }}',
	'header_textcolor'                                    => '{{ data.header_textcolor }}',
	'page_background_color'                               => '{{ data.page_background_color }}',
	'secondary_background_color'                          => '{{ data.secondary_background_color }}',
	'absolute_header_background_color'                    => '{{ data.absolute_header_background_color }}',
	'main_text_color'                                     => '{{ data.main_text_color }}',
	'headline_text_color'                                 => '{{ data.headline_text_color }}',
	'headline_text_color_eighty_nine_color'               => '{{ data.headline_text_color_eighty_nine_color }}',
	'tertiary_background'                                 => '{{ data.tertiary_background }}',
	'ninety_of_tertiary_background'                       => '{{ data.ninety_of_tertiary_background }}',
	'link_color'                                          => '{{ data.link_color }}',
	'eighty_six_of_link_color'                            => '{{ data.eighty_six_of_link_color }}',
	'link_hover_color'                                    => '{{ data.link_hover_color }}',
	'secondary_link_color'                                => '{{ data.secondary_link_color }}',
	'button_background_color'                             => '{{ data.button_background_color }}',
	'button_text_color'                                   => '{{ data.button_text_color }}',
	'tertiary_link_color'                                 => '{{ data.tertiary_link_color }}',
	'button_hover_text_color'                             => '{{ data.button_hover_text_color }}',
	'button_background_hover_color'                       => '{{ data.button_background_hover_color }}',
	'blog_background_odd'                                 => '{{ data.blog_background_odd }}',
	'blog_background_even'                                => '{{ data.blog_background_even }}',
	'blog_background_even_color'                          => '{{ data.blog_background_even_color }}',
	'border_color'                                        => '{{ data.border_color }}',
	'border_color_ninety_nine_color'                      => '{{ data.border_color_ninety_nine_color }}',
	'textcolor_with_background'                           => '{{ data.textcolor_with_background }}',
	'textcolor_with_background_eighty_two_color'          => '{{ data.textcolor_with_background_eighty_two_color }}',
	'team_section_title_color'                            => '{{ data.team_section_title_color }}',
	);
	?>
	<script type="text/html" id="tmpl-signify-color-scheme">
		<?php echo signify_get_color_scheme_css( $colors ); ?>
	</script>
	<?php
}
add_action( 'customize_controls_print_footer_scripts', 'signify_color_scheme_css_template' );

/**
 * Enqueues front-end CSS for the page background color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_page_background_color_css() {
	$color_scheme          = signify_get_color_scheme();
	$default_color         = $color_scheme[2];
	$page_background_color = get_theme_mod( 'page_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $page_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Page Background Color */
		input[type="text"],
		input[type="email"],
		.site-header-cart .cart-contents .count,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		textarea,
		select,
		.select2-container--default .select2-selection--single,
		.screen-reader-text:focus,
		.team-section .team-content-wrapper .hentry .entry-container:before,
		.boxed-layout .site,
		.ui-state-active,
		.ui-widget-content .ui-state-active,
		.ui-widget-header .ui-state-active,
		.feature-slider-wrapper .entry-summary a,
		.feature-slider-wrapper a.more-link,
		.has-header-image .custom-header-content .entry-summary a,
		.has-header-image .custom-header-content a.more-link,
		#contact-section input[type="submit"],
		.navigation-classic .sub-menu {
			background-color: %1$s;
		}

		.wp-playlist-light, #sticky-playlist-section, 
		#sticky-playlist-section .wp-playlist-tracks {
		    background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $page_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_page_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary background color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_secondary_background_color_css() {
	$color_scheme          			= signify_get_color_scheme();
	$default_color         			= $color_scheme[3];
	$secondary_background_color 	= get_theme_mod( 'secondary_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_background_color === $default_color ) {
	return;
	}

	$css = '
		/* Secondary Background Color */
		.section:nth-child(even),
		.mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-total, 
		.mejs-controls .mejs-time-rail .mejs-time-total,
		.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-loaded, 
		.signify-mejs-container.mejs-container .mejs-controls .mejs-time-rail .mejs-time-float,
		ins,
		table thead,
		.sidebar .widget-wrap,
		#primary-search-wrapper .menu-inside-wrapper,
		.menu-inside-wrapper,
		.mobile-social-search,
		#footer-newsletter,
		mark,
		.custom-header,
		ins,
		ul.tabs.wc-tabs li.active a,
		.woocommerce-Tabs-panel,
		.shop_table thead th,
		ul.wc_payment_methods.payment_methods.methods li,
		.comment-respond,
		.widget_shopping_cart,
		pre,
		.widget .ui-tabs .ui-tabs-panel {
		    background-color: %1$s;
		}

		#sticky-playlist-section {
		    border-color: %1$s;
		}

		@media screen and (min-width: 1024px) {
	    .navigation-classic .site-header .sub-menu,
	    .navigation-classic .site-header .children {
	        background-color: %1$s;
	    }
	}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $secondary_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_secondary_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the Absolute Header Background Color for Inner Pages.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_absolute_header_background_color_css() {
	$color_scheme          			= signify_get_color_scheme();
	$default_color         			= $color_scheme[4];
	$absolute_header_background_color 		= get_theme_mod( 'absolute_header_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $absolute_header_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Absolute Header Background Color for Inner Pages */
		.site-header {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $absolute_header_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_absolute_header_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the main text color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_main_text_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[5];
	$main_text_color = get_theme_mod( 'main_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $main_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Main Text Color */
		body,
		input,
		select,
		optgroup,
		textarea,
		table a,
		input::placeholder,
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		blockquote,
		#promotion-section .play-video .play-button:hover:before,
		#promotion-section .play-video .play-button:focus:before,
		.entry-container .entry-content,
		.entry-container .entry-summary {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $main_text_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_main_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the headline text color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_headline_text_color_css() {
	$color_scheme        = signify_get_color_scheme();
	$default_color       = $color_scheme[6];
	$headline_text_color = get_theme_mod( 'headline_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $headline_text_color === $default_color ) {
	return;
	}

	// Convert secondary background hex color to rgba.
	$headline_text_color_rgb = signify_hex2rgb( $headline_text_color );

	// If the rgba values are empty return early.
	if ( empty( $headline_text_color_rgb ) ) {
		return;
	}

	$headline_text_color_eighty_nine_color	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.89)', $headline_text_color_rgb );

	$css = '
		/* Headline Text Color */
		h1,
		h2,
		h3,
		h4,
		h5,
		h6,
		#product-content-section  .product-container a.button,
		.author-name,
		.comment-reply-link,
		.author-title,
		.comment-respond .comment-form p label {
			color: %1$s;
		}

		@media and (min-width: 768px) {
		    .testimonials-content-wrapper.section.testimonial-wrapper .cycle-pager span { 
		        color: %1$s;
		    }
		}

		/* 89% of heading color */

		.section-title,
		.portfolio-section-headline .section-title,
		.entry-title a,
		.drop-cap:first-letter,
		.vcard,
		.position,
		.entry-meta a,
		.section-description-wrapper,
		.section-title-wrapper+.section-description,
		.section-title+.section-description,
		.section-title-wrapper+.section-subtitle,
		.section-heading-wrapper>.section-description,
		.section-title+.section-description,
		.section-heading-wrapper>.section-subtitle {
			color: %2$s;
		}

	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $headline_text_color, $headline_text_color_eighty_nine_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_headline_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the Tertiary Background color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_tertiary_background_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[7];
	$tertiary_background = get_theme_mod( 'tertiary_background', $default_color );

	// Don't do anything if the current color is the default.
	if ( $tertiary_background === $default_color ) {
		return;
	}

	// Convert secondary background hex color to rgba.
	$tertiary_background_rgb = signify_hex2rgb( $tertiary_background );

	// If the rgba values are empty return early.
	if ( empty( $tertiary_background_rgb ) ) {
		return;
	}

	$ninety_of_tertiary_background	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.9)', $tertiary_background_rgb );

	$css = '
		/* Tertiary Background Color */
		#colophon,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button,
		.team-content-wrapper .entry-container,
		.playlist-content-wrapper .wp-playlist,
		#gallery-section .gallery-item .gallery-icon a:before,
		#gallery-section .tiled-gallery .tiled-gallery-item a:before,
		.app-section .entry-container:after,
		.playlist-content-wrapper .wp-playlist .wp-playlist-tracks > div:hover,
		.playlist-content-wrapper .wp-playlist .wp-playlist-tracks > div:focus {
			background-color: %1$s;
		}

		.team-content-wrapper .entry-content:before,
		.team-content-wrapper .entry-summary:before {
		    background-image: linear-gradient(to bottom, %2$s, %1$s);
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $tertiary_background, $ninety_of_tertiary_background ) );
}
add_action( 'wp_enqueue_scripts', 'signify_tertiary_background_css', 11 );

/**
 * Enqueues front-end CSS for the link color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_link_color_css() {
	$color_scheme    = signify_get_color_scheme();
	$default_color   = $color_scheme[8];
	$link_color = get_theme_mod( 'link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_color === $default_color ) {
		return;
	}

	// Convert Link Color hex color to rgba.
	$link_color_rgb          = signify_hex2rgb( $link_color );
	
	$eighty_six_of_link_color = vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.86)', $link_color_rgb );

	$css = '
		/* Link Color */
		a,
		.sidebar .widget-wrap p,
		.sidebar .widget-wrap li a,
		span.breadcrumb a:hover,
		span.breadcrumb a:focus,
		.custom-header-content .site-header-text .entry-meta a:hover,
		.custom-header-content .site-header-text .entry-meta a:focus,
		.dropdown-toggle,
		.site-header-menu .menu-inside-wrapper .nav-menu li button,
		.ui-state-active a,
		.ui-state-active a:link,
		.ui-state-active a:visited,
		.social-search-wrapper .menu-social-container li a,
		.menu-social-container a,
		.sidebar nav.social-navigation ul li a:hover,
		.sidebar nav.social-navigation ul li a:focus,
		.screen-reader-text:focus,
		td#today,
		.toggled-on.active:before,
		.comment-respond .comment-form p.is-focused label,
		.contact-section.section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li a  {
			color: %1$s;
		}

		ins {
		    background-color: %1$s;
		}

		/* 86% of link color */

		.nav-title,
		.post-title,
		.comments-title,
		.comment-reply-title,
		.woocommerce.has-header-image .woocommerce-breadcrumb a:hover,
		.woocommerce.has-header-image .woocommerce-breadcrumb a:focus,
		span.breadcrumb a:hover,
		span.breadcrumb a:focus,
		.widget_recent_entries li a {
		   color:%2$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $link_color, $eighty_six_of_link_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_link_color_css', 11 );


/**
 * Enqueues front-end CSS for the link hover color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_link_hover_color_css() {
	$color_scheme     = signify_get_color_scheme();
	$default_color    = $color_scheme[9];
	$link_hover_color = get_theme_mod( 'link_hover_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_hover_color === $default_color ) {
		return;
	}

	$css = '
	Link Hover Color */
		p.stars:hover a:before,
		p.stars:focus a:before,
		.star-rating span:before,
		p.stars.selected a.active:before,
		p.stars.selected a:not(.active):before,
		p.stars.selected a.active~a:before,
		p.stars a:hover~a:before,
		p.stars a:focus~a:before,
		.site-header-cart .cart-contents:hover .count,
		.site-header-cart .cart-contents:focus .count,
		.page-numbers.current,
		.page-links .current,
		#site-header-cart-wrapper a.cart-contents .count,
		.menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a,
		#reviews .comment-respond .comment-form-rating .stars span a.active:before,
		#reviews .comment-respond .comment-form-rating .stars.selected span a:not(.active):before {
			color: %1$s;
		} 

		a:hover,
		a:focus,
		.site-info a:hover,
		.site-info a:focus,
		.has-background-image  .entry-container .entry-meta a:hover,
		.has-background-image  .entry-container .entry-meta a:focus,
		.has-background-image  .entry-container .entry-title a:hover,
		.has-background-image  .entry-container .entry-title a:focus,
		.post-title:hover,
		.post-title:focus,
		.woocommerce .woocommerce-breadcrumb a:hover,
		.woocommerce .woocommerce-breadcrumb a:focus,
		.site-title a:hover,
		.site-title a:focus,
		#testimonial-content-section .owl-prev:hover, 
		#testimonial-content-section .owl-prev:focus, 
		#testimonial-content-section .owl-next:hover,
		#testimonial-content-section .owl-next:focus,
		.single footer .entry-meta a:hover,
		.single footer .entry-meta a:focus,
		#site-footer-navigation li a:hover,
		#site-footer-navigation li a:focus,
		#social-footer-navigation li a:hover,
		#social-footer-navigation li a:focus,
		.has-background-image .entry-title a:hover,
		.has-background-image .entry-title a:focus,
		.has-background-image .entry-meta a:hover,
		.has-background-image .entry-meta a:focus,
		.archive-post-wrap .hentry:nth-child(2n) .entry-title a:hover,
		.archive-post-wrap .hentry:nth-child(2n) .entry-title a:focus,
		.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:hover,
		.archive-post-wrap .hentry:nth-child(2n) .entry-meta a:focus,
		.team-content-wrapper .entry-container .entry-title a:hover,
		.team-content-wrapper .entry-container .entry-title a:focus,
		.team-content-wrapper .entry-container .entry-meta a:hover,
		.team-content-wrapper .entry-container .entry-meta a:focus,
		.team-content-wrapper .entry-container .social-navigation a:hover,
		.team-content-wrapper .entry-container .social-navigation a:focus,
		.wp-playlist-tracks .wp-playlist-caption:hover,
		.wp-playlist-tracks .wp-playlist-caption:focus,
		.signify-mejs-container.mejs-container button:hover,
		.signify-mejs-container.mejs-container button:focus,
		.woocommerce-loop-product__title:hover,
		.woocommerce-loop-product__title:focus,
		span.price span.woocommerce-Price-amount:hover,
		span.price span.woocommerce-Price-amount:focus,
		.events-content-wrapper .entry-meta a:hover,
		.events-content-wrapper .entry-meta a:focus,
		.widget_recent_entries li a:hover,
		.widget_recent_entries li a:focus,
		.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:hover,
		.menu-inside-wrapper .main-navigation .nav-menu ul > li > a:focus,
		button.dropdown-toggle:hover,
		button.dropdown-toggle:focus,
		.site-header-menu .menu-inside-wrapper .nav-menu li button:hover,
		.site-header-menu .menu-inside-wrapper .nav-menu li button:focus,
		.portfolio-content-wrapper .hentry .entry-container a:hover,
		.portfolio-content-wrapper .hentry .entry-container a:focus,
		button#wp-custom-header-video-button:hover,
		button#wp-custom-header-video-button:focus,
		.widget .ui-state-default a:hover,
		.widget .ui-state-default a:focus,
		.widget .ui-widget-content .ui-state-default a:hover,
		.widget .ui-widget-content .ui-state-default a:focus,
		.widget .ui-widget-header .ui-state-default a:hover,
		.widget .ui-widget-header .ui-state-default a:focus,
		body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:hover,
		body .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu ul .current_page_item>a:focus,
		.tag-cloud-link:hover,
		.tag-cloud-link:focus,
		.nav-title:hover,
		.nav-title:focus,
		.menu-social-container a:hover,
		.menu-social-container a:focus,
		.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:hover,
		.slider-content-wrapper .entry-container .entry-container-wrap .entry-title a:focus,
		.portfolio-content-wrapper .hentry .entry-container a:hover,
		.portfolio-content-wrapper .hentry .entry-container a:focus,
		.portfolio-content-wrapper .hentry .entry-container .entry-meta time:hover,
		.portfolio-content-wrapper .hentry .entry-container .entry-meta time:focus,
		.social-search-wrapper .menu-social-container li a:hover,
		.social-search-wrapper .menu-social-container li a:focus,
		.sidebar .widget-wrap .more-link:hover,
		.sidebar .widget-wrap .more-link:focus,
		.author a:hover,
		.author a:focus,
		.entry-meta a:hover,
		.entry-meta a:focus,
		.entry-title a:hover,
		.entry-title a:focus,
		.site-footer td#prev a:hover,
		.site-footer td#prev a:focus,
		.site-footer td#next a:hover,
		.site-footer td#next a:focus,
		.comment-reply-link:hover,
		.comment-reply-link:focus,
		aside.footer-widget-area a:hover,
		aside.footer-widget-area a:focus,
		.author-section-title:hover,
		.author-section-title:focus,
		.comment-permalink:hover,
		.comment-permalink:focus,
		.comment-edit-link:hover,
		.comment-edit-link:focus,
		.nav-subtitle:hover,
		.nav-subtitle:focus,
		.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:hover,
		.testimonials-content-wrapper.section.testimonial-wrapper .entry-title a:focus,
		#site-generator .menu-social-container a:hover,
		#site-generator .menu-social-container a:focus,
		.widget-wrap li a:hover,
		.widget-wrap li a:focus,
		.main-navigation ul:not(.sub-menu)>li>a:hover,
		.main-navigation ul:not(.sub-menu)>li>a:focus,
		.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:hover,
		.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:focus,
		#site-header-cart-wrapper a.cart-contents:hover,
		#site-header-cart-wrapper a.cart-contents:focus,
		.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:hover,
		.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a:focus,
		#featured-content-section .section-content-wrapper .hentry .more-link:hover,
		#featured-content-section .section-content-wrapper .hentry .more-link:focus,
		.service-section .hentry .more-link:hover,
		.service-section .hentry .more-link:focus,
		#portfolio-content-section .hentry .more-link:hover,
		#portfolio-content-section .hentry .more-link:focus,
		#service-section.has-background-image .hentry .more-link:hover,
		#service-section.has-background-image .hentry .more-link:focus,
		#service-section .hentry .more-link:hover,
		#service-section .hentry .more-link:focus,
		#stats-section .hentry .more-link:hover,
		#stats-section .hentry .more-link:focus,
		#stats-section.has-background-image .hentry .more-link:hover,
		#stats-section.has-background-image .hentry .more-link:focus,
		.navigation.pagination a:hover,
		.navigation.pagination a:focus,
		.playlist-content-wrapper .signify-mejs-container.mejs-container button:hover,
		.playlist-content-wrapper .signify-mejs-container.mejs-container button:focus{
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $link_hover_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_link_hover_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary link color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_secondary_link_color_css() {
	$color_scheme         = signify_get_color_scheme();
	$default_color        = $color_scheme[10];
	$secondary_link_color = get_theme_mod( 'secondary_link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_link_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Link Color */
		ins,
		.entry-breadcrumbs a,
		.woocommerce .woocommerce-breadcrumb a,
		p.stars a,
		.single footer .entry-meta a,
		p.stars a:before,
		.controller:before,
		.tag-cloud-link,
		.select2-results__option,
		body.no-header-media-image .site-header .site-header-main .site-header-menu .menu-inside-wrapper .main-navigation .nav-menu .current_page_item > a,
		#footer-newsletter .wrapper .section-description,
		.widget-wrap span.post-date,
		.contact-section .entry-container a,
		.archive .section-content-wrapper .more-link .readmore,
		.featured-content-section .hentry .more-link,
		.faq-section .hentry .more-link,
		.team-section .hentry .more-link,
		.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:before,
		.testimonials-content-wrapper.section.testimonial-wrapper .cycle-prev:after,
		.testimonials-content-wrapper.section.testimonial-wrapper .cycle-next:before,
		.clients-content-wrapper .controller .cycle-pager span,
		.testimonials-content-wrapper .cycle-pager:after,
		.slider-content-wrapper .entry-container .entry-container-wrap .entry-summary,
		.portfolio-content-wrapper .filter-button-group button,
		.testimonials-content-wrapper .entry-title a,
		.testimonials-content-wrapper.section.testimonial-wrapper .hentry,
		.scrollup a:hover:before,
		.scrollup a:focus:before,
		.sidebar .widget-wrap .more-link,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:hover,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link:focus,
		.archive-content-wrap .section-content-wrapper.layout-one .entry-container>.entry-meta .posted-on a,
		.team-section .entry-meta,
		.author-label,
		.entry-title .sub-title,
		.section-heading-wrapper .entry-title .sub-title,
		.section-heading-wrapper .entry-title span,
		.author-section-title,
		.comment-permalink,
		.comment-edit-link,
		.entry-title span,
		.nav-subtitle,
		.nav-menu .menu-item-has-children>a:before,
		.nav-menu .menu_item_has_children>a:before,
		input,
		select,
		optgroup,
		textarea,
		aside.footer-widget-area .widget,
		aside.footer-widget-area svg,
		aside.footer-widget-area a,
		.site-info,
		.playlist-content-wrapper .mejs-time,
		span.woocommerce-Price-amount,
		.catch-breadcrumb.center .entry-breadcrumbs, 
		.catch-breadcrumb.center .woocommerce-breadcrumb {
			color: %1$s;
		}
	';
	wp_add_inline_style( 'signify-block-style', sprintf( $css, $secondary_link_color) );
}
add_action( 'wp_enqueue_scripts', 'signify_secondary_link_color_css', 11 );

/**
 * Enqueues front-end CSS for the Button background color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_background_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[11];
	$button_background_color 	= get_theme_mod( 'button_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Background Color */
		.more-link,
		.onsale,
		.button,
		.entry-content button,
		.entry-summary button,
		button,
		#scrollup,
		.slider-content-wrapper .controllers .cycle-prev,
		.slider-content-wrapper .controllers .cycle-next,
		input[type="submit"],
		button[type="submit"],
		.scrollup a,
		.sticky-post,
		#team-dots li.active:after,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus,
		.wp-block-button__link,
		#infinite-handle .ctis-load-more button,
		.menu-inside-wrapper #site-header-cart-wrappe li>a,
		.contact-section .entry-container ul.contact-details li .fa,
		nav.navigation.posts-navigation .nav-links a,
		.woocommerce-pagination ul.page-numbers li .page-numbers.current,
		.archive-content-wrap .pagination .page-numbers.current,
		.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
		.catch-instagram-feed-gallery-widget-wrapper .button,
		.sticky-label,
		#signify-logo-slider-section .owl-dots .owl-dot span {
			border-color: %1$s;
		}


		blockquote,
		#signify-logo-slider-section .owl-prev:hover,
		#signify-logo-slider-section .owl-prev:focus,
		#signify-logo-slider-section .owl-next:hover,
		#signify-logo-slider-section .owl-next:focus,
		#signify-logo-slider-section .owl-dots .owl-dot.active span,
		.woocommerce .products .product-container .button {
		    border-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the button text color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_text_color_css() {
	$color_scheme      = signify_get_color_scheme();
	$default_color     = $color_scheme[12];
	$button_text_color = get_theme_mod( 'button_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Text Color */
		.more-link,
		.onsale,
		#scrollup,
		.entry-content button,
		.entry-summary button,
		.slider-content-wrapper .controllers .cycle-prev,
		.slider-content-wrapper .controllers .cycle-next,
		button,
		#primary-search-wrapper .search-container button,
		input[type="submit"],
		.button,
		.scroll-down,
		.scrollup a:before,
		.page-numbers:hover,
		.page-numbers:focus,
		button[type="submit"],
		button#wp-custom-header-video-button,
		#infinite-handle .ctis-load-more button,
		nav.navigation.posts-navigation .nav-links a,
		.woocommerce-pagination ul.page-numbers li:hover,
		.archive-content-wrap .pagination .page-numbers:hover,
		.archive-content-wrap .pagination .page-numbers:focus,
		.woocommerce-pagination ul.page-numbers li:focus,
		.archive-content-wrap .pagination .page-numbers.current,
		.woocommerce-pagination ul.page-numbers li .page-numbers.current,
		#portfolio-content-section .entry-container,
		.contact-details li .fa,
		.slider-content-wrapper #featured-slider-prev:hover:before,
		.slider-content-wrapper #featured-slider-next:hover:before,
		.slider-content-wrapper #featured-slider-prev:focus:before,
		.slider-content-wrapper #featured-slider-next:focus:before,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:hover:before,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button:focus:before,
		.nav-menu .menu-item-has-children>a:hover:before,
		.nav-menu .menu-item-has-children>a:focus:before,
		.nav-menu .menu_item_has_children>a:hover:before,
		.nav-menu .menu_item_has_children>a:focus:before,
		.contact-section .entry-container ul.contact-details li .fa,
		.cart-collaterals .shop_table.shop_table_responsive .cart-subtotal,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover a,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus a {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the Header and Tertiary Color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_tertiary_link_color_css() {
	$color_scheme        = signify_get_color_scheme();
	$default_color       = $color_scheme[13];
	$tertiary_link_color = get_theme_mod( 'tertiary_link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $tertiary_link_color === $default_color ) {
		return;
	}

	$css = '
		/* Header and Tertiary Color */
		.feature-slider-wrapper .entry-container .entry-title,
		.feature-slider-wrapper .entry-container .entry-title span,
		.feature-slider-wrapper .entry-container .entry-summary p,
		.feature-slider-wrapper .entry-container .entry-content p,
		.custom-header-content .site-header-text,
		.custom-header-content .site-header-text .entry-meta a,
		.custom-header-content-wrapper .section-title,
		.signify-mejs-container.mejs-container button,
		.wp-playlist-current-item,
		.mejs-time,
		.navigation-classic .main-navigation .nav-menu > li >a,
		.navigation-classic button.menu-toggle,
		#site-header-cart-wrapper a.cart-contents,
		.menu-toggle,
		.menu-label,
		.section .owl-carousel .owl-nav button.owl-next, 
		.section .owl-carousel .owl-nav button.owl-prev {
			color: %1$s;
		}

		@media and (min-width: 1200px) {
		.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:hover, 
		.navigation-classic .main-navigation ul:not(.sub-menu) > li > a:focus {
	           color: %1$s;
	        }
	    }

	    .menu-toggle:hover .menu-label,
	    .menu-toggle:focus .menu-label,
	    .menu-toggle:hover:before,
	    .menu-toggle:focus:before {
	        color: %1$s;
	    } 

	    @media screen and (min-width: 768px) {
	    	.has-header-image #site-header-cart-wrapper a.cart-contents:hover, 
			.has-header-image #site-header-cart-wrapper a.cart-contents:focus,
			.absolute-header button.menu-toggle:hover,
			.absolute-header button.menu-toggle:focus
		   	#site-header-cart-wrapper a.cart-contents:hover,
			#site-header-cart-wrapper a.cart-contents:focus {
	            color: %1$s;
	        }
	    }

		.owl-carousel .owl-dots button.owl-dot span,
		#feature-slider-section .owl-nav button:hover,
		#feature-slider-section .owl-nav button:focus {
		    background-color: %1$s;
		}

		.owl-carousel .owl-dots button.owl-dot.active span {
		    border-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $tertiary_link_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_tertiary_link_color_css', 11 );


/**
 * Enqueues front-end CSS for the button hover text color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_hover_text_color_css() {
	$color_scheme            = signify_get_color_scheme();
	$default_color           = $color_scheme[14];
	$button_hover_text_color = get_theme_mod( 'button_hover_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_hover_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Hover Text Color */
		.more-link:hover,
		.more-link:focus,
		button:hover,
		button:focus,
		.site-title a:hover,
		.site-title a:focus,
		#signify-logo-slider-section .owl-prev:hover,
		#signify-logo-slider-section .owl-prev:focus,
		#signify-logo-slider-section .owl-next:hover, 
		#signify-logo-slider-section .owl-next:focus,
		.button:hover,
		.button:focus,
		.entry-content button:hover,
		.entry-content button:focus,
		.entry-summary button:hover,
		.entry-summary button:focus,
		#social-search-toggle svg:hover,
		#social-search-toggle svg:focus,
		input[type="submit"]:hover,
		input[type="submit"]:focus,
		button[type="submit"]:hover,
		button[type="submit"]:focus,
		#primary-search-wrapper .search-container button:hover,
		#primary-search-wrapper .search-container button:focus,
		#infinite-handle .ctis-load-more button:hover,
		#infinite-handle .ctis-load-more button:focus,
		nav.navigation.posts-navigation .nav-links a:hover,
		nav.navigation.posts-navigation .nav-links a:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:hover,
		.contact-section .section-content-wrap .hentry .entry-container .stay-connected .social-links-menu li:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.feature-slider-wrapper .entry-summary a:hover,
		.feature-slider-wrapper .entry-summary a:focus,
		#contact-section input[type="submit"]:hover,
		#contact-section input[type="submit"]:focus,
		.has-header-image .custom-header-content .more-link:hover,
		.has-header-image .custom-header-content .more-link:focus,
		.has-header-image .site-title a:hover,
		.has-header-image .site-title a:focus,
		#product-content-section .product-container a.button:hover,
		#product-content-section .product-container a.button:focus,
		#scrollup:hover,
		#scrollup:focus {
			color: %1$s;
		}

	    #menu-toggle:hover .menu-label,
		#menu-toggle:focus .menu-label,
		#menu-toggle:hover:before,
		#menu-toggle:focus:before,
		.scrollup a:hover:before,
		.scrollup a:focus:before {
		    color: %1$s;
		}

		@media screen and (min-width: 1200px) {
		    .menu-inside-wrapper .main-navigation > .nav-menu >.current_page_item>a {
		        color: %1$s;
		    }
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_hover_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_hover_text_color_css', 11 );

/**
 * Enqueues front-end CSS for the Button Hover Background Color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_button_background_hover_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[15];
	$button_background_hover_color 	= get_theme_mod( 'button_background_hover_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_background_hover_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Hover Background Color */
		.more-link:hover,
		.more-link:focus,
		#contact-section.has-background-image input[type="submit"]:hover,
		#contact-section.has-background-image input[type="submit"]:focus,
		.button:hover,
		.button:focus,
		#scrollup:hover,
		#scrollup:focus,
		#signify-logo-slider-section .owl-prev:hover,
		#signify-logo-slider-section .owl-prev:focus,
		#signify-logo-slider-section .owl-next:hover, 
		#signify-logo-slider-section .owl-next:focus,
		button:hover, 
		button:focus, 
		input[type="submit"]:hover,
		input[type="submit"]:focus,
		button[type="submit"]:hover,
		button[type="submit"]:focus,
		.wp-block-button__link:hover,
		.wp-block-button__link:focus,
		.woocommerce .products .product-container .button:hover,
		.woocommerce .products .product-container .button:focus,
		#infinite-handle .ctis-load-more button:hover,
		#infinite-handle .ctis-load-more button:focus,
		.slider-content-wrapper .cycle-next:hover,
		.slider-content-wrapper .cycle-next:focus,
		.slider-content-wrapper .cycle-prev:hover,
		.slider-content-wrapper .cycle-prev:focus,
		nav.navigation.posts-navigation .nav-links a:hover,
		nav.navigation.posts-navigation .nav-links a:focus,
		.woocommerce-pagination ul.page-numbers li .page-numbers:hover,
		.woocommerce-pagination ul.page-numbers li .page-numbers:focus,
		.archive-content-wrap .pagination .page-numbers:hover,
		.archive-content-wrap .pagination .page-numbers:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.feature-slider-wrapper .entry-summary a:hover,
		.feature-slider-wrapper .entry-summary a:focus,
		#contact-section input[type="submit"]:hover,
		#contact-section input[type="submit"]:focus,
		.has-header-image .custom-header-content .more-link:hover,
		.has-header-image .custom-header-content .more-link:focus {
			border-color: %1$s;
		}

		#signify-logo-slider-section {
		    background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $button_background_hover_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_button_background_hover_color_css', 11 );

/**
 * Enqueues front-end CSS for the Blog Background Odd
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_blog_background_odd_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[16];
	$blog_background_odd 	= get_theme_mod( 'blog_background_odd', $default_color );

	// Don't do anything if the current color is the default.
	if ( $blog_background_odd === $default_color ) {
		return;
	}

	$css = '
		/* Blog Background Odd */
		.archive-post-wrap .hentry {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $blog_background_odd ) );
}
add_action( 'wp_enqueue_scripts', 'signify_blog_background_odd_css', 11 );

/**
 * Enqueues front-end CSS for the Blod Background Even.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_blog_background_even_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[17];
	$blog_background_even 	= get_theme_mod( 'blog_background_even', $default_color );

	// Don't do anything if the current color is the default.
	if ( $blog_background_even === $default_color ) {
		return;
	}

	$css = '
		/* Blog Background Even */
		.archive-post-wrap .hentry:nth-child(2n) {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $blog_background_even ) );
}
add_action( 'wp_enqueue_scripts', 'signify_blog_background_even_css', 11 );

/**
 * Enqueues front-end CSS for the Blod Background Even.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_blog_background_even_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[18];
	$blog_background_even_color 	= get_theme_mod( 'blog_background_even_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $blog_background_even_color === $default_color ) {
		return;
	}

	$css = '
		/* Blog Background Even Color */
		.archive-post-wrap .hentry:nth-child(2n) .entry-title a,
		.archive-post-wrap .hentry:nth-child(2n) .entry-meta a,
		.archive-post-wrap .hentry:nth-child(2n) .entry-summary p,
		.archive-post-wrap .hentry:nth-child(2n) .entry-content p {
		    color: %1$s;
		} 
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $blog_background_even_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_blog_background_even_color_css', 11 );

/**
 * Enqueues front-end CSS for the border color.
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_border_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[19];
	$border_color 	= get_theme_mod( 'border_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $border_color === $default_color ) {
		return;
	}

	// Convert Border Color hex color to rgba.
	$border_color_rgb          = signify_hex2rgb( $border_color );
	
	$border_color_ninety_nine_color = vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.99)', $border_color_rgb );

	$css = '
		/* Border Color */
		nav.navigation,
		.site-content .archive-posts-wrapper .posts-navigation .nav-links .nav-previous,
		.woocommerce-tabs .panel,
		#signify-logo-slider-section .owl-prev,
		#signify-logo-slider-section .owl-next,
		.woocommerce-tabs ul.tabs li.active a:after,
		.woocommerce-tabs ul.tabs:after,
		.calendar_wrap tbody tr:first-child,
		.calendar_wrap tbody tr:last-child,
		tfoot,
		tfoot tr td,
		.author-info,
		.wpcf7 div input, 
		.wpcf7 div textarea,
		#promotion-section .play-button,
		.navigation-classic .main-navigation ul ul,
		.woocommerce-shorting-wrapper,
		.woocommerce-tabs ul.tabs.wc-tabs li,
		.menu-wrapper .widget_shopping_cart ul.woocommerce-mini-cart li,
		.entry-summary form.cart,
		.widget_recent_entries li,
		.team-section .team-content-wrapper .hentry .team-social-profile .social-links-menu,
		input[type="submit"],
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="number"],
		input[type="tel"],
		input[type="range"],
		input[type="date"],
		input[type="month"],
		input[type="week"],
		input[type="time"],
		input[type="datetime"],
		input[type="datetime-local"],
		input[type="color"],
		textarea,
		table,
		caption,
		.sidebar.widget-area .widget-wrap,
		table th,
		table thead tr,
		table thead th,
		thead th,
		tbody th,
		tbody td,
		tbody tr,
		table.shop_table_responsive tr td,
		table tbody tr,
		table.shop_table_responsive tbody tr:last-child,
		.shop_table tfoot tr td,
		.shop_table tfoot tr th,
		table.shop_table.woocommerce-checkout-review-order-table .cart_item td,
		table.shop_table.woocommerce-checkout-review-order-table tr td,
		table.shop_table.woocommerce-checkout-review-order-table tr th,
		.rtl tbody td:last-child,
		.rtl table thead th:last-child,
		.select2-container--default .select2-selection--single,
		table.woocommerce-grouped-product-list.group_table,
		table.woocommerce-grouped-product-list.group_table td,
		table.variations,
		table.variations td,
		.woocommerce-pagination ul.page-numbers li .page-numbers,
		.archive-content-wrap .navigation.pagination .page-numbers,
		.woocommerce-posts-wrapper .summary.entry-summary .woocommerce-product-rating,
		.cart-collaterals .order-total,
		#payment .wc_payment_methods .payment_box,
		.products .product,
		select,
		header .site-header-main,
		abbr,
		acronym,
		.product-quantity input[type="number"],
		.coupon input[type="text"],
		.site-header-main .menu-inside-wrapper,
		.catch-instagram-feed-gallery-widget-wrapper .button,
		.site-header-cart .widget_shopping_cart,
		.woocommerce-grouped-product-list tr,
		.mobile-social-search,
		.widget .ui-tabs .ui-tabs-panel,
		.site-header-menu .menu-inside-wrapper .nav-menu button:focus,
		header .site-header-menu .menu-inside-wrapper .main-navigation .sub-menu li:last-child,
		header .site-header-menu .menu-inside-wrapper .main-navigation .children li:last-child,
		.comment-body,
		.promotion-headline-wrapper.section .section-content-wrap .inner-container .more-button .more-link,
		.section:nth-child(2n) + .site-content,
		.archive-content-wrap .section-content-wrapper.layout-one .hentry .hentry-inner .entry-container>.entry-meta,
		.comments-area,
		.playlist-content-wrapper .wp-playlist .wp-playlist-tracks {
			border-color: %1$s;
		}

		/* 99% of border color*/
		.page .site-main .entry-footer .entry-meta > span:not(.edit-link),
		.single .site-main .entry-footer .entry-meta > span:not(.edit-link),
		.events-content-wrapper .hentry,
		.tagcloud a,
		textarea:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="number"]:focus,
		input[type="tel"]:focus,
		input[type="range"]:focus,
		input[type="date"]:focus,
		input[type="month"]:focus,
		input[type="week"]:focus,
		input[type="time"]:focus,
		input[type="datetime"]:focus,
		input[type="datetime-local"]:focus,
		input[type="color"]:focus,
		.wpcf7 div input:focus, 
		.wpcf7 div textarea:focus {
			border-color: %2$s;	
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $border_color, $border_color_ninety_nine_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_border_color_css', 11 );

/**
 * Enqueues front-end CSS for Text color with background image
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_textcolor_with_background_css() {
	$color_scheme              = signify_get_color_scheme();
	$default_color             = $color_scheme[20];
	$textcolor_with_background = get_theme_mod( 'textcolor_with_background', $default_color );

	// Don't do anything if the current color is the default.
	if ( $textcolor_with_background === $default_color ) {
		return;
	}

	// Convert secondary background hex color to rgba.
	$textcolor_with_background_rgb          = signify_hex2rgb( $textcolor_with_background );
	
	$textcolor_with_background_eighty_two_color = vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.82)', $textcolor_with_background_rgb );


	$css = '
		/* Text color with background color */
		.scroll-down,
		.site-info a,
		.job-label,
		.has-background-image input[type="text"],
		.has-background-image input[type="email"],
		.has-background-image input,
		.has-background-image input[type="url"],
		.has-background-image input[type="password"],
		.has-background-image input[type="search"],
		.has-background-image input[type="number"],
		.has-background-image input[type="tel"],
		.has-background-image input[type="range"],
		.has-background-image input[type="date"],
		.has-background-image input[type="month"],
		.has-background-image input[type="week"],
		.has-background-image input[type="time"],
		.has-background-image input[type="datetime"],
		.has-background-image input[type="datetime-local"],
		.has-background-image input[type="color"],
		.has-background-image textarea,
		.has-background-image select,
		.play-button-text,
		.custom-header .entry-breadcrumbs a,
		.woocommerce .custom-header .woocommerce-breadcrumb a,
		.has-header-image .custom-header .catch-breadcrumb .entry-breadcrumbs, 
		.has-header-image .custom-header .catch-breadcrumb .woocommerce-breadcrumb,
		aside.footer-widget-area a,
		.team-content-wrapper .owl-prev:before,
		.team-content-wrapper .owl-next:before,
		#team-content-section .team-content-wrapper.owl-carousel .owl-nav button.disabled,
		.team-content-wrapper .entry-container .entry-title a,
		.team-content-wrapper .entry-container .entry-header,
		.team-content-wrapper .entry-container .entry-meta a,
		.team-content-wrapper .entry-container .entry-summary p,
		.team-content-wrapper .entry-container .entry-content p,
		.team-content-wrapper .entry-container .social-navigation a,
		.custom-header-content .entry-title .sub-title,
		#signify-logo-slider-section .entry-summary p,
		#signify-logo-slider-section .entry-title span, 
		.hero-content-wrapper.has-background-image .entry-container,
		.portfolio-content-wrapper .hentry .entry-container a,
		.portfolio-content-wrapper .hentry .entry-container .entry-meta time,
		.portfolio-content-wrapper .hentry .entry-container .entry-summary,
		.custom-header-content .entry-container,
		.custom-header-content .entry-container .entry-title,
		.ewnewsletter.has-background-image .section-title,
		.site-footer .widget-wrap .widget-title,
		.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .hentry,
		.testimonials-content-wrapper.section.testimonial-wrapper.has-background-image .position,
		.slider-content-wrapper.content-frame .entry-container .entry-title a,
		.slider-content-wrapper.content-frame .entry-container .entry-container-wrap .entry-summary,
		aside.footer-widget-area .widget-title,
		.playlist-content-wrapper .signify-mejs-container.mejs-container button,
		.playlist-content-wrapper .wp-playlist-current-item,
		.has-background-image .section-title,
		#contact-section.has-background-image .hentry,
		#contact-section.has-background-image .entry-title,
		.has-background-image  .entry-container .entry-meta a,
		.has-background-image  .entry-container .entry-title a,
		.has-background-image  .entry-container .entry-title,
		.has-background-image  .entry-container .entry-title span,
		.has-background-image  .entry-container .entry-summary,
		.has-background-image  .entry-container .entry-summary p,
		.has-background-image  .entry-container .entry-content,
		.has-background-image  .entry-container .entry-content p,
		.content-color-white .entry-container .entry-title a,
		.content-color-white .entry-container .entry-title,
		.content-color-white .entry-container .entry-content p,
		.content-color-white .entry-container .entry-summary p,
		.has-background-image .woocommerce-loop-product__title,
		#promotion-section .play-button,
		.has-background-image .products .button,
		#feature-slider-section .owl-nav button:hover:before,
		#feature-slider-section .owl-nav button:focus:before,
		#stats-section.has-background-image .hentry .more-link,
		#service-section.has-background-image .hentry .more-link,
		.playlist-content-wrapper .wp-playlist-caption {
			color: %1$s;
		}

		.feature-slider-wrapper .entry-summary a,
		.feature-slider-wrapper .entry-content a,
		.feature-slider-wrapper a.more-link,
		.has-header-image .custom-header-content .entry-summary a,
		.has-header-image .custom-header-content .entry-content a,
		.has-header-image .custom-header-content a.more-link,
		#contact-section.has-background-image input[type="submit"],
		#promotion-section .play-video .play-button:hover,
		#promotion-section .play-video .play-button:focus {
			background-color: %1$s;
		}

		/* 82% of text color with background */

		.has-background-image .event-list-description .entry-summary,
		.has-background-image .event-list-description .entry-summary  p,
		.has-background-image .event-list-description .entry-content,
		.has-background-image .event-list-description .entry-content  p,
		#contact-section.has-background-image .entry-content p,
		#contact-section.has-background-image .entry-summary p,
		.playlist-content-wrapper .wp-playlist-tracks,
		#social-footer-navigation li a,
		#site-footer-navigation li a,
		.footer-contact,
		#contact-section .entry-container .entry-content .contact-details label,
		#contact-section .entry-container .entry-summary .contact-details label,
		.has-background-image .section-description-wrapper,
		.has-background-image .section-title-wrapper+.section-description,
		.has-background-image .section-title+.section-description,
		.has-background-image .section-title-wrapper+.section-subtitle,
		.has-background-image .section-heading-wrapper>.section-description,
		.has-background-image .section-title+.section-description,
		.has-background-image .section-heading-wrapper>.section-subtitle {
			color: %2$s;
		}
	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $textcolor_with_background, $textcolor_with_background_eighty_two_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_textcolor_with_background_css', 11 );


/**
 * Enqueues front-end CSS for the Team Section title Color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */
function signify_team_section_title_color_css() {
	$color_scheme   = signify_get_color_scheme();
	$default_color  = $color_scheme[21];
	$team_section_title_color 	= get_theme_mod( 'team_section_title_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $team_section_title_color === $default_color ) {
		return;
	}

	$css = '
		/* Team Section title color */

		#team-content-section .section-title {
		    color: %1$s;
		}

	';

	wp_add_inline_style( 'signify-block-style', sprintf( $css, $team_section_title_color ) );
}
add_action( 'wp_enqueue_scripts', 'signify_team_section_title_color_css', 11 );

/**
 * Enqueues front-end CSS for the Contact and Newsletter background color
 *
 * @since 1.0.0
 *
 * @see wp_add_inline_style()
 */

/**
 * Converts a HEX value to RGB.
 *
 * @since 1.0.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function signify_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}
